import webpack from "webpack";
import WebpackChain from "webpack-chain";
import Bundler from "./interfaces/Bundler";
import { DeepPartial } from "ts-essentials";
import BundlerConfig from "./interfaces/BundlerConfig";
import { EnvironmentTypes } from "./types/EnvironmentTypes";
import BundlerEnvironment from "./interfaces/BundlerEnvironment";
import { BrowserSyncPluginConfig } from "./interfaces/plugin-config-interfaces/BrowserSyncPluginConfig";
import { Options as ESLintOptions } from 'eslint-webpack-plugin';
export default abstract class AbstractBundler {
    config: BundlerConfig;
    env: BundlerEnvironment;
    webpackChain: WebpackChain;
    bundles: Array<webpack.Configuration>;
    constructor(mode?: EnvironmentTypes, config?: DeepPartial<BundlerConfig>);
    aliases(aliases: {
        [key: string]: string;
    }): this;
    aggressiveVendorSplitting(): this;
    build(): Array<webpack.Configuration>;
    browserSync(options?: BrowserSyncPluginConfig): this;
    chainWebpack(callback: (webpackChain: WebpackChain, env: BundlerEnvironment) => any): this;
    copy(from: string, to?: string): this;
    dontClean(exclude: Array<string> | string): this;
    eslint(options: ESLintOptions): this;
    html(): this;
    htmlVariables(variables: any): this;
    plugin<T, U>(Plugin: {
        new (Bundler: Bundler, options?: U): T;
    }, options?: U): this;
    proxy(from: string, to: string, options?: {
        changeOrigin: boolean;
    }): this;
    purgeCss(paths: Array<string>, config?: {
        whiteListPatterns?: Array<RegExp>;
        whitelistSelectors?: Array<string>;
        whitelistPatternsChildren?: Array<RegExp>;
    }): this;
    globalSassIncludes(filePaths: any, rx?: RegExp): this;
    varieConfig(variables: Record<string, unknown>): this;
    webWorkers(): this;
    private addBundle;
    private argumentsHas;
    private bundle;
    private inspect;
    private setupConfig;
    private setupEnv;
    private presets;
    protected updateJavascriptLoaders(): void;
}
