"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var hash_sum_1 = __importDefault(require("hash-sum"));
var Loader = (function () {
    function Loader(bundler, options) {
        this.options = options;
        this.bundler = bundler;
        this.register();
    }
    Loader.prototype.generateCacheConfig = function (loader, relatedPackages, configFiles) {
        var _this = this;
        if (relatedPackages === void 0) { relatedPackages = []; }
        if (configFiles === void 0) { configFiles = []; }
        var configs = {};
        var versions = {
            "varie-bundler": require("../../package.json").version,
        };
        relatedPackages.forEach(function (relatedPackage) {
            versions[relatedPackage] = require(relatedPackage + "/package.json").version;
        });
        configFiles.forEach(function (configFile) {
            configs[configFile] = _this.getFile(configFile);
        });
        return {
            cacheIdentifier: (0, hash_sum_1.default)({
                loader: loader,
                configs: configs,
                versions: versions,
            }),
            cacheDirectory: this.getPath("node_modules/.cache/" + loader),
        };
    };
    Loader.prototype.getPath = function (_path) {
        return path_1.default.resolve(this.bundler.config.root, _path);
    };
    Loader.prototype.getFile = function (_path) {
        var filePath = this.getPath(_path);
        if (fs_1.default.existsSync(filePath)) {
            return fs_1.default.readFileSync(filePath, "utf-8");
        }
        return null;
    };
    return Loader;
}());
exports.default = Loader;
//# sourceMappingURL=Loader.js.map