"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function multiCompiler(configs) {
    var devServerPort;
    var writeToDiskFunctions = [];
    for (var configName in configs) {
        var builder = configs[configName];
        if (!builder.build) {
            throw Error("To use Multi-Compiler you must supply a webpack-chain.");
        }
        var writeToDiskFunction = builder.webpackChain.devServer.get("writeToDisk");
        if (writeToDiskFunction) {
            writeToDiskFunctions.push(writeToDiskFunction);
        }
    }
    var builds = [];
    Object.values(configs).map(function (bundler, index) {
        if (index === 0) {
            devServerPort = bundler.config.webpack.devServer.port;
            bundler.webpackChain.devServer.set("writeToDisk", function (filePath) {
                return writeToDiskFunctions.reduce(function (writeToDiskFunction, val) {
                    return writeToDiskFunction && writeToDiskFunction(filePath) && val;
                });
            });
        }
        else {
            bundler.webpackChain.devServer.port(devServerPort);
            bundler.webpackChain.devServer.delete("writeToDisk");
        }
        builds.push.apply(builds, bundler.build());
    });
    return builds;
}
exports.default = multiCompiler;
//# sourceMappingURL=multiCompiler.js.map